@@ -46,6 +46,9 @@ export VERBOSE=0
 # set MOZ_APP_LAUNCHER for gnome-session
 export MOZ_APP_LAUNCHER
 
+# let Thunderbird detect the system dictionaries
+export DICPATH=/usr/share/hunspell
+
 declare -a TB_ARGS=()
 
 for ARG in "$@"; do
